@@ -21,7 +21,7 @@ use Travel::Status::DE::HAFAS::Polyline qw(decode_polyline);
 use Travel::Status::DE::HAFAS::Journey;
 use Travel::Status::DE::HAFAS::StopFinder;
 
-our $VERSION = '4.01';
+our $VERSION = '4.02';
 
 # {{{ Endpoint Definition
 
@@ -270,6 +270,9 @@ sub new {
 			}
 		}
 
+		my $maxjny   = $conf{results}   // 30;
+		my $duration = $conf{lookahead} // -1;
+
 		$req = {
 			svcReqL => [
 				{
@@ -278,10 +281,10 @@ sub new {
 						type     => ( $conf{arrivals} ? 'ARR' : 'DEP' ),
 						stbLoc   => { lid => $lid },
 						dirLoc   => undef,
-						maxJny   => 30,
+						maxJny   => $maxjny,
 						date     => $date,
 						time     => $time,
-						dur      => -1,
+						dur      => $duration,
 						jnyFltrL => [
 							{
 								type  => "PROD",
@@ -736,7 +739,7 @@ monitors
 
 =head1 VERSION
 
-version 4.01
+version 4.02
 
 =head1 DESCRIPTION
 
@@ -763,7 +766,9 @@ I<opt> must contain either a B<station> or a B<journey> flag:
 =item B<station> => I<station>
 
 Request station board (arrivals or departures) for I<station>, e.g. "Essen HBf" or
-"Alfredusbad, Essen (Ruhr)". Results are available via C<< $status->results >>.
+"Alfredusbad, Essen (Ruhr)". The station must be specified either by name or by
+EVA ID (e.g. 8000080 for Dortmund Hbf).
+Results are available via C<< $status->results >>.
 
 =item B<journey> => B<{> B<id> => I<tripid> [, B<name> => I<line> ] B<}>
 
@@ -806,11 +811,23 @@ I<mot2>, ...  will be returned.  The supported modes depend on B<service>, use
 B<get_services> or B<get_service> to get the supported values.
 Only relevant in station board mode.
 
+=item B<lookahead> => I<int>
+
+Request arrivals/departures that occur up to I<int> minutes after the specified datetime.
+Default: -1 (do not limit results by time).
+Only relevant in station board mode.
+
 =item B<lwp_options> => I<\%hashref>
 
 Passed on to C<< LWP::UserAgent->new >>. Defaults to C<< { timeout => 10 } >>,
 pass an empty hashref to call the LWP::UserAgent constructor without arguments.
 
+=item B<results> => I<count>
+
+Request up to I<count> results.
+Default: 30.
+Only relevant in station board mode.
+
 =item B<service> => I<service>
 
 Request results from I<service>, defaults to "DB".
